<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Microsoft.UI.Xaml

Windows Runtime (WinRT) APIs for for the `Microsoft.UI.Xaml` namespace.

This package provides the `winrt.microsoft.ui.xaml` module.
